@@ -454,8 +454,11 @@ def isClosedMotif(motif_identifier : str, level : int = -1) -> bool:
     arities, roles, motif = sma.parseMotifIdentifier(motif_identifier)
     signature             = sma.multiSignature(arities)
     motif_info            = sma.motifInfo(signature)
-    positions             = sma.matchPositions(motif_info.signature, arities, roles)
-    abstract_level        = positions.index(level) if level > 0 else motif_info.signature.index(2)
+    if level >= 0:
+        positions         = sma.matchPositions(motif_info.signature, arities, roles)
+        abstract_level    = positions.index(level)
+    else:
+        abstract_level    = motif_info.signature.index(2)
     if abstract_level not in motif_info.projections:
         raise NotImplementedError('closed/open relations not implemented for motifs with signature %s on abstract level %d'\
                                   % (str(motif_info.signature), abstract_level))
