@@ -176,7 +176,8 @@ def countMotifsAuto(G : nx.Graph,
             # cast motif class to correct type
             key = motif_info.classes_type(motif)
             if key not in counted:
-                raise TypeError("Unrecognizable motif identifier %s[%s]." % (cl, motif))
+                raise TypeError("Unrecognizable motif class in identifier %s[%s]."\
+                                % (cl, motif))
             partial_results["%s[%s]" % (cl, motif)] = counted[key]
     
     return partial_results, total_results
