@@ -108,7 +108,7 @@ def classify2Motif(G : nx.Graph, motif) -> bool:
     :param G: the SEN
     :param motif: a pair of two vertices, the motif
     """
-    return G.has_edge(*motif)
+    return int(G.has_edge(*motif))
 
 class TwoMotifClassificator(MotifClassificator):
     """
@@ -118,7 +118,7 @@ class TwoMotifClassificator(MotifClassificator):
     def __call__(self, motif):
         return classify2Motif(self.G, motif)
     def info(self):
-        return sma.Motif3Info
+        return sma.Motif2Info
 
     
 def classify3pMotif(G : nx.Graph, motif) -> int:
