@@ -163,13 +163,15 @@ def motifInfo(signature):
             return obj
     raise NotImplementedError('motifs with signature %s not implemented' % str(signature))
 
-def supportedSignatures() -> list:
+def supportedSignatures() -> iter:
     """
-    Returns a list of all supported signatures.
+    Returns an iterator yielding all supported signatures.
     
-    :returns: list of all supported signatures.
+    .. code :: Python
+        
+        print(list(sma.supportedSignatures()))
+        
+    
+    :returns: iterator yielding all supported signatures.
     """
-    result = []
-    for _, obj in _infoObjects():
-        result.append(obj.signature)
-    return result
\ No newline at end of file
+    return map(lambda x : x[1].signature, _infoObjects())
