@@ -75,8 +75,10 @@ MOTIF4_AUT = numpy.array([2, 2, 2, 2,
                           4, 4, 2, 2])
 MOTIF3_AUT = numpy.array([1, 2, 1, 1, 2, 1])
 
-MODEL_ERDOS_RENYI   = 'erdos_renyi'
-MODEL_ACTORS_CHOICE = 'actors_choice'
+# models for random baselines
+MODEL_ERDOS_RENYI     = 'erdos_renyi'
+MODEL_ACTORS_CHOICE   = 'actors_choice'
+MODEL_FIXED_DENSITIES = 'fixed_densities'
 
 def binaryCodeToClass4Motifs(digits : int) -> str:
     """
